/*!
 * @package     Guest Support
 * @author      RcaTheme.com <support@rcatheme.com>
 * @license     https://www.gnu.org/licenses/gpl-3.0.html GPLv3
 * @link        https://www.rcatheme.com
 * @copyright   2024 RcaTheme.com, All rights resered.
 */

// Add Agent
(function($){
	$.guest_support_AddAgent = function() {
		// Get users to select as agent
        var resultarea = $('div.guest-support-dropdown-search-menu'),
		$text = $('div.guest-support-dropdown-search-text').html(),
		$input = $('input#guest_support_dropdown_search_box'),
		guest_support_TypingInterval = 500,
    	guest_support_TypingTimer;

		// Change Agent id on click
		$(document).on('click', '.guest-support-dropdown-search-menu > .item', function(event) {
			event.stopPropagation();
			var $this = $(this),
				$selected_id = $this.attr('data-value'),
				$selected_text = $this.html();
			$text = $selected_text;
			$('input#guest_support_dropdown_search_main').val($selected_id);
			$('div.guest-support-dropdown-search-text').html($text);
			$input.val($text);
			resultarea.hide(50);
		});
		$(document).on("click", function() {
			$input.val($text);
			resultarea.hide(50);
		});

		$('input#guest_support_dropdown_search_box').on("click", function(event) {
			event.stopPropagation();
		});

		$input.on('focus', function (event) {
			$input.val('');
			resultarea.show(50);
		});
		$input.on('keyup', function (event) {
			clearTimeout(guest_support_TypingTimer);
			guest_support_TypingTimer = setTimeout(guest_support_DoneTyping, guest_support_TypingInterval);
		});
		$input.on('keydown', function () {
			clearTimeout(guest_support_TypingTimer);
		});
		function guest_support_DoneTyping () {
			resultarea.html('');
			var searchterm = $input.val();
			if (searchterm != '' && searchterm.length > 1) {
				var post_vars = new Array();
				post_vars.push({name:'guest_support_handler', value: 'ajax'});
				post_vars.push({name:'request', value: 'get_users'});
				post_vars.push({name:'searchterm', value: searchterm});
				var data = jQuery.post('', post_vars);

				data.done(function(reply_data) {
					var response_json = jQuery.parseJSON(reply_data);
					resultarea.html(response_json);
				});
			} else {
				resultarea.html('');
			}
		}
    };
})(jQuery);

jQuery(document).ready(function($) {
	// Tabs
	// Get the current URL hash
    var guest_support_Tab_hash = window.location.hash;

    if ( guest_support_Tab_hash && guest_support_Tab_hash.startsWith( '#guest_support_tab_' ) ) {
        // Extract the tab name from the hash
        let tabName = guest_support_Tab_hash.substring( 1 );

        // Find the corresponding li and div elements
        let $tabLi = $( 'li[data-guest-support-tab="' + tabName + '"]' );
        let $tabDiv = $( 'div#' + tabName );

        // If the elements exist, add the 'active' class
        if ( $tabLi.length && $tabDiv.length ) {
			$('ul#guest-support-tab-menu li.guest-support-tab-item').removeClass('active');
			$('div.guest-support-tab-content').hide().removeClass("active");
            $tabLi.addClass( 'active' );
            $tabDiv.fadeIn();
        }
    }

	var guest_support_Tab = $('ul#guest-support-tab-menu li.guest-support-tab-item');
	var guest_support_TabContent = $('div.guest-support-tab-content');
	guest_support_Tab.click(function() {
		guest_support_TabContent.hide().removeClass("active");
		guest_support_Tab.removeClass("active");
		$(this).addClass("active");
		var activeguest_support_Tab = $(this).attr("data-guest-support-tab");
		$("div#"+activeguest_support_Tab).fadeIn();

		// Update the URL hash without scrolling
		let targetTab = $( this ).find( 'a' ).attr( 'href' );
        if ( history.pushState ) {
            history.pushState( null, null, targetTab );
        } else {
            window.location.hash = targetTab;
        }
	});

	var guest_support_Tab_a = $('ul#guest-support-tab-menu li.guest-support-tab-item > a');
	guest_support_Tab_a.click(function(event) {
		event.preventDefault();

        let targetTab = $( this ).attr( 'href' );

        // Update the URL hash without scrolling
        if ( history.pushState ) {
            history.pushState( null, null, targetTab );
        } else {
            window.location.hash = targetTab;
        }
	});

	$(document).on('click', 'ul.guest-support-tabs-dd-menu li.guest-support-tabs-dd-item', function(event) {
		var $this = $(this);
		var $thisDiv = $this.closest('div.guest-support-tabs-dd-wrapper');
		var $thisUl = $this.closest('ul.guest-support-tabs-dd-menu');
		var $thisText = $thisDiv.find('span.guest-support-tabs-dd-toggle');
		var $thisAttr = $this.attr("data-guest-support-tab");
		var $allLi = $thisDiv.find('li.guest-support-tabs-dd-item');

		if (!$this.hasClass('guest-support-active')) {
			$thisText.html($this.html());
			$allLi.removeClass('guest-support-active');
			$allLi.css('opacity', '1');
			$this.css('opacity', '0.5');
			$this.addClass('guest-support-active');
			$thisUl.hide();
			setTimeout(function(){
				$thisUl.show();
			}, 300);
			$('div.guest-support-tabs-dd-content').hide();
			$('#' + $thisAttr).fadeIn();
		}
	});
	$('input.guest-support-input-tab-name').keyup(function() {
		var $this = $(this);
		var $thisValue = $this.val();
		var $thisId = $this.attr("id");
		var $liSpan = $( 'ul.guest-support-tabs-dd-menu li.guest-support-tabs-dd-item span#' + $thisId );
		var $divSpan = $( 'div.guest-support-tabs-dd-wrapper span.guest-support-tabs-dd-toggle > span' );
		$liSpan.html( $thisValue );
		$divSpan.html( $thisValue );

		if ( $thisValue.trim() ) {
			$liSpan.addClass('has-content');
			$divSpan.addClass('has-content');
		} else {
			$liSpan.removeClass('has-content');
			$divSpan.removeClass('has-content');
		}
	});
	$(document).on('click', '#guest-support-delete', function() {
		return confirm("Are you sure? You can't undo this action.");
	});
	// Modals
	$('div.guest-support-modal').appendTo('body');
	$(document).on('click', '#guest_support_open_modal', function() {
		var $this = $(this);
		var $thisContent = $this.attr("data-modal");

		if ( $thisContent == 'guest_support_modal_create_ticket_by_agent' ) {
            $('div#guest_support_create_ticket_by_agent div#guest_support_field_errormsg').hide().html("");
        }

		$('#' + $thisContent).addClass('guest-support-modal-active');
		$('body').addClass('guest-support-modal-active');
	});
	$(document).on('click', '#guest_support_modal_close', function() {
		guest_support_ModalClose();
		/* $('div.guest-support-modal').removeClass('guest-support-modal-active');
		$('body').removeClass('guest-support-modal-active');
		$('div#guest_support_modal_main_content').html(""); */
	});

	function guest_support_ModalClose() {
		$('div.guest-support-modal').removeClass('guest-support-modal-active');
		$('body').removeClass('guest-support-modal-active');
		$('div#guest_support_modal_main_content').html("");
	}

	// Add fields
	var $guest_support_Preloader = '<div class="guest-support-loader"><span></span><span></span><span></span><span></span><span></span></div>';

	// Edit fields
	$(document).on('click', '#guest_support_edit_field', function() {
		var $this = $(this),
			$value = $this.attr("field-type"),
			$editType = $this.attr("field-edit"),
			$thisList = $this.closest('li'),
			$thisListId = $this.closest('li').attr('id'),

			$inputName = $thisList.find('input#guest_support_field_list_name').val(),
			$inputLabel = $thisList.find('input#guest_support_field_list_label').val(),
			$inputPlaceholder = $thisList.find('input#guest_support_field_list_placeholder').val(),
			$inputRequired = $thisList.find('input#guest_support_field_list_required').val(),
			$inputDescription = $thisList.find('textarea#guest_support_field_list_description').val(),
			$inputErrorMessage = $thisList.find('textarea#guest_support_field_list_error_message').val(),
			$inputColsize = $thisList.find('input#guest_support_field_list_colsize').val(),

			$fieldtoform = $thisList.find('input#guest_support_field_list_fieldtoform').val(),
			$showonticketview = $thisList.find('input#guest_support_field_list_showonticketview').val(),
			$addtoemail = $thisList.find('input#guest_support_field_list_addtoemail').val(),
			$login_required = $thisList.find('input#guest_support_field_list_login_required').val(),

			$min = $thisList.find('input#guest_support_field_list_min').val(),
			$max = $thisList.find('input#guest_support_field_list_max').val(),
			$options = $thisList.find('textarea#guest_support_field_list_options').val(),
			$hidden_field_value = $thisList.find('input#guest_support_field_list_hidden_value').val(),
			$custom_field_content = $thisList.find('textarea#guest_support_field_list_customtext').val();

		$thisList.addClass('guest_support_field_updating');

		if ( $value == 'departments' ) {
			var $showonform = $thisList.find('input#guest_support_field_list_showonform').val();
			var $default_department = $thisList.find('input#guest_support_field_list_default_department').val();
		}

		var $content = '<ul id="guest_support_field_type_' + $value + '" class="guest-support-field-contents">' + $('ul#guest_support_field_type_' + $value).html() + '</ul>';

		// Change modal title
		$('span#guest_support_modal_edit_field_title').html( $inputName );

		// Activate modal
		$('#guest_support_modal_edit_fields').addClass('guest-support-modal-active');
		$('body').addClass('guest-support-modal-active');
		$('div#guest_support_modal_main_content').html($guest_support_Preloader);

		setTimeout(function(){
			$('div#guest_support_modal_main_content').html($content);

			// Delete field name option for core field.
			if ( $editType == 'core' ) {
				$('div#guest_support_modal_main_content li.guest_support_field_list_name').remove();
				$('div#guest_support_modal_main_content li.guest_support_field_list_required').remove();
				$('div#guest_support_modal_main_content li.guest_support_field_list_showonticketview').remove();
				$('div#guest_support_modal_main_content li.guest_support_field_list_fieldtoform').remove();
				$('div#guest_support_modal_main_content li.guest_support_field_list_addtoemail').remove();
				$('div#guest_support_modal_main_content li.guest_support_field_list_login_required').remove();
			} else {
				$('div#guest_support_modal_main_content li.guest_support_field_list_name').hide();
			}
			// Change modal inputs
			$('div#guest_support_modal_main_content input#field_name').val( $inputName );
			$('div#guest_support_modal_main_content input#field_label').val( $inputLabel );
			$('div#guest_support_modal_main_content input#field_placeholder').val( $inputPlaceholder );
			$('div#guest_support_modal_main_content select#field_required').val( $inputRequired ).change();
			$('div#guest_support_modal_main_content textarea#field_description').val( $inputDescription );
			$('div#guest_support_modal_main_content textarea#field_error_message').val( $inputErrorMessage );
			$('div#guest_support_modal_main_content select#guest_support_field_list_colsize').val( $inputColsize ).change();

			$('div#guest_support_modal_main_content select#guest_support_field_list_fieldtoform').val( $fieldtoform ).change();
			$('div#guest_support_modal_main_content select#guest_support_field_list_showonticketview').val( $showonticketview ).change();
			$('div#guest_support_modal_main_content select#guest_support_field_list_addtoemail').val( $addtoemail ).change();
			$('div#guest_support_modal_main_content select#guest_support_field_list_login_required').val( $login_required ).change();

			$('div#guest_support_modal_main_content input#field_min').val( $min );
			$('div#guest_support_modal_main_content input#field_max').val( $max );
			$('div#guest_support_modal_main_content textarea#field_options').val( $options );
			$('div#guest_support_modal_main_content input#field_value').val( $hidden_field_value );
			$('div#guest_support_modal_main_content textarea#field_content').val( $custom_field_content );

			if ( $value == 'departments' ) {
				if ( $showonform == '1' ) {
					$('div#guest_support_modal_main_content input#showonform_departments_1').attr('checked', 'checked');
					$('li.guest_support_field_list_default_department > div.list-departments').hide();
				} else if ( $showonform == '0' ) {
					$('div#guest_support_modal_main_content input#showonform_departments_0').attr('checked', 'checked');
					$('li.guest_support_field_list_default_department > div.list-departments').show();
				}
				$('div#guest_support_modal_main_content select#field_default_department').val( $default_department ).change();
			}

			// Change data-field att on edit button
			$('div#guest_support_modal_edit_fields a#guest_support_modal_edit_fields_submit').attr('data-group', $thisListId);
		}, 500);
	});

	// Process update
	$(document).on('click', '#guest_support_modal_edit_fields_submit', function() {
		var $this = $(this);
		var $dataGroup = $this.attr('data-group');

		// Get the field group list id
		var $thisList = $this.closest('div.guest-support-modal-container-wrapper');

		// Show pre-loader
		$thisList.find('.guest-support-modal-footer div.guest-support-loader').show();

		// Get inputs
		var $inputName = $thisList.find('.guest-support-modal-content input#field_name').val(),
			$inputLabel = $thisList.find('.guest-support-modal-content input#field_label').val(),
			$inputPlaceholder = $thisList.find('.guest-support-modal-content input#field_placeholder').val(),
			$inputRequired = $thisList.find('.guest-support-modal-content select#field_required').val(),
			$inputDescription = $thisList.find('.guest-support-modal-content textarea#field_description').val(),
			$inputErrorMessage = $thisList.find('.guest-support-modal-content textarea#field_error_message').val(),
			$min = $thisList.find('.guest-support-modal-content input#field_min').val(),
			$max = $thisList.find('.guest-support-modal-content input#field_max').val(),
			$options = $thisList.find('.guest-support-modal-content textarea#field_options').val(),
			$hidden_field_value = $thisList.find('.guest-support-modal-content input#field_value').val(),
			$custom_field_content = $thisList.find('.guest-support-modal-content textarea#field_content').val(),
			$colSize = $thisList.find('.guest-support-modal-content select#guest_support_field_list_colsize').val(),
			$fieldtoform = $thisList.find('.guest-support-modal-content select#guest_support_field_list_fieldtoform').val(),
			$showonticketview = $thisList.find('.guest-support-modal-content select#guest_support_field_list_showonticketview').val(),
			$addtoemail = $thisList.find('.guest-support-modal-content select#guest_support_field_list_addtoemail').val(),
			$login_required = $thisList.find('.guest-support-modal-content select#guest_support_field_list_login_required').val(),
			$inputType = $thisList.find('.guest-support-modal-content input#guest_support_this_field_input_type').val();

		if ( $options ) {
			var $optionsArray = $options.split(/\r?\n/);
		}

		// Departments
		var $deptShowonform = $thisList.find('.guest-support-modal-content input[name="showonform_departments"]:checked').val(),
			$deptDefaultDepartment = $thisList.find('.guest-support-modal-content select#field_default_department').val(),
			$deptShowonformYes = $('span#guest_support_texthelper_yes').html(),
			$deptShowonformNo = $('span#guest_support_texthelper_no').html();

		$('li#' + $dataGroup + ' input#guest_support_field_list_showonform').val( $deptShowonform );
		$('li#' + $dataGroup + ' select#guest_support_field_list_departments').val( $deptDefaultDepartment ).change();
		$('li#' + $dataGroup + ' input#guest_support_field_list_default_department').val( $deptDefaultDepartment );
		if ( $deptShowonform == '0' ) {
			$('li#' + $dataGroup + ' span#guest_support_form_field_label_showonform').html( $deptShowonformNo );
		} else {
			$('li#' + $dataGroup + ' span#guest_support_form_field_label_showonform').html( $deptShowonformYes );
		}

		// Update fields of this group
		$('li#' + $dataGroup + ' label').html($inputLabel);
		$('li#' + $dataGroup + ' input#guest_support_field_list_visible').attr('placeholder', $inputPlaceholder );
		$('li#' + $dataGroup + ' textarea#guest_support_field_list_visible').attr('placeholder', $inputPlaceholder );
		$('li#' + $dataGroup + ' input#guest_support_field_list_label').val( $inputLabel );
		$('li#' + $dataGroup + ' input#guest_support_field_list_placeholder').val( $inputPlaceholder );
		$('li#' + $dataGroup + ' textarea#guest_support_field_list_description').val( $inputDescription );
		$('li#' + $dataGroup + ' textarea#guest_support_field_list_error_message').val( $inputErrorMessage );

		$('li#' + $dataGroup + ' input#guest_support_field_list_min').val( $min );
		$('li#' + $dataGroup + ' input#guest_support_field_list_max').val( $max );
		$('li#' + $dataGroup + ' input#guest_support_field_list_hidden_value').val( $hidden_field_value );
		$('li#' + $dataGroup + ' textarea#guest_support_field_list_options').val( $options );
		$('li#' + $dataGroup + ' textarea#guest_support_field_list_customtext').val( $custom_field_content );
		$('li#' + $dataGroup + ' div.guest_support_field_list_visible_customcontent').html( $custom_field_content );

		if ( $inputType == 'select' ) {
			var $html_select = $('li#' + $dataGroup + ' select#guest_support_field_list_visible');
			$html_select.empty(); // remove old options
			if ( $options && $optionsArray.length !== 0 ) {
				$.each($optionsArray, function(index, value) {
					// Initialize variables
					let isSelected = false;
				
					// Check if '##selected' is present in the value
					if (value.includes('##selected')) {
						isSelected = true;
						value = value.replace('##selected', '').trim();
					}

					let optionValue = value;
					let optionLabel = value;
				
					// Check if '||' separator is present in the value
					if (value.includes('||')) {
						[optionValue, optionLabel] = value.split('||').map(str => str.trim());
					}
				
					// Create the option element
					let $option = $("<option></option>")
						.attr("value", optionValue)
						.text(optionLabel);
				
					// Add the selected attribute if necessary
					if (isSelected) {
						$option.attr("selected", "selected");
					}
				
					// Append the option to the select element
					$html_select.append($option);
				});
			}
		} else if ( $inputType == 'radio' ) {
			$html_radio = '';
			if ( $options && $optionsArray.length !== 0 ) {
				$.each($optionsArray, function(index, value) {
					// Initialize variables
					let isChecked = false;
				
					// Check if '##checked' is present in the value
					if (value.includes('##checked')) {
						isChecked = true;
						value = value.replace('##checked', '').trim();
					}

					let optionValue = value;
					let optionLabel = value;
				
					// Check if '||' separator is present in the value
					if (value.includes('||')) {
						[optionValue, optionLabel] = value.split('||').map(str => str.trim());
					}
				
					// Create the radio input element
					let inputId = $inputName + '_' + index;
					let $radioInput = '<input name="demo_checkbox_' + $inputName + '" type="radio" id="' + inputId + '" value="' + optionValue + '"';
				
					// Add the checked attribute if necessary
					if (isChecked) {
						$radioInput += ' checked';
					}
				
					$radioInput += '>';
				
					// Create the label element
					let $label = '<label for="' + inputId + '" class="guest-support-field-checkbox-label">' + optionLabel + '</label>';
				
					// Append the radio input and label to the list item
					$html_radio += '<li>' + $radioInput + $label + '</li>';
				});
			}
			$('li#' + $dataGroup + ' ul.guest-support-field-checkbox').html($html_radio);
		} else if ( $inputType == 'checkbox' ) {
			$html_checkbox = '';
			if ( $options && $optionsArray.length !== 0 ) {
				$.each($optionsArray, function(index, value) {
					// Initialize variables
					let isChecked = false;
				
					// Check if '##checked' is present in the value
					if (value.includes('##checked')) {
						isChecked = true;
						value = value.replace('##checked', '').trim();
					}

					let optionValue = value;
					let optionLabel = value;
				
					// Check if '||' separator is present in the value
					if (value.includes('||')) {
						[optionValue, optionLabel] = value.split('||').map(str => str.trim());
					}
				
					// Create the checkbox input element
					let inputId = $inputName + '_' + index;
					let $checkboxInput = '<input name="demo_checkbox_' + $inputName + '" type="checkbox" id="' + inputId + '" value="' + optionValue + '"';
				
					// Add the checked attribute if necessary
					if (isChecked) {
						$checkboxInput += ' checked';
					}
				
					$checkboxInput += '>';
				
					// Create the label element
					let $label = '<label for="' + inputId + '" class="guest-support-field-checkbox-label">' + optionLabel + '</label>';
				
					// Append the checkbox input and label to the list item
					$html_checkbox += '<li>' + $checkboxInput + $label + '</li>';
				});
			}
			$('li#' + $dataGroup + ' ul.guest-support-field-checkbox').html($html_checkbox);
		}

		if ($inputName) {
			$('li#' + $dataGroup + ' input#guest_support_field_list_name').val( $inputName );
			$('li#' + $dataGroup + ' span#guest_support_form_field_label_name').html( $inputName );
		}
		if ($inputRequired) {
			var $inputRequiredText = $thisList.find('.guest-support-modal-content select#field_required option:selected').text();
			$('li#' + $dataGroup + ' input#guest_support_field_list_required').val( $inputRequired );
			$('li#' + $dataGroup + ' span#guest_support_form_field_label_required').html( $inputRequiredText );
		}

		/** Column Size */
		if ( $inputType != 'hidden' ) {
			$('li#' + $dataGroup).removeClass('guest-support-size-100').removeClass('guest-support-size-50').removeClass('guest-support-size-33-3');
			$('li#' + $dataGroup).addClass('guest-support-size-' + $colSize);
			$('li#' + $dataGroup + ' input#guest_support_field_list_colsize').val( $colSize );
			$('li#' + $dataGroup + ' span#guest_support_form_field_label_colsize').html( $colSize + '%' );
		}

		$('li#' + $dataGroup + ' input#guest_support_field_list_fieldtoform').val( $fieldtoform );
		$('li#' + $dataGroup + ' input#guest_support_field_list_showonticketview').val( $showonticketview );
		$('li#' + $dataGroup + ' input#guest_support_field_list_addtoemail').val( $addtoemail );
		$('li#' + $dataGroup + ' input#guest_support_field_list_login_required').val( $login_required );
		/** End Column Size */
		$('li#' + $dataGroup).removeClass('guest_support_field_updating');

		setTimeout(function() {
			$thisList.find('.guest-support-modal-footer div.guest-support-loader').hide();
			guest_support_ModalClose();
		}, 500);
	});
	$(document).on('click', '.guest-support-add-edit-fields-modal a#guest_support_modal_close', function() {
		$('div.guest-support-add-edit-fields-modal div#guest_support_modal_main_content').html('');
		$('div.guest-support-add-edit-fields-modal select#guest_support_add_field_type').val('').change();
	});

	// Add/change Agent
	$.guest_support_AddAgent();

	// Show hide SMTP options
	$(document).on('change', 'select#guest_support_select_mailer', function(event) {
        var $thisval = $(this).val();
		if ( $thisval == 'wp' ) {
			$('div#guest_support_settings_smtp_credentials').hide();
		}
		else
		{
			$('div#guest_support_settings_smtp_credentials').show();
		}
	});

	// Select/unselect all tickets
	$(document).on('change', 'input#guest_support_tickets_select_all', function(event) {
		if($(this).is(':checked')) {
            $('input#guest_support_tickets_select').prop('checked', true);
			$('a.guest-support-mass-delete').addClass('active');
        } else {
            $('input#guest_support_tickets_select').prop('checked', false);
			$('a.guest-support-mass-delete').removeClass('active');
        }
	});

	$('input#guest_support_tickets_select').change(function(){
        if ($('input#guest_support_tickets_select:checked').length > 0) {
            $('a.guest-support-mass-delete').addClass('active');
        } else {
            $('a.guest-support-mass-delete').removeClass('active');
        }
    });

	// Delete selected tickets
	$(document).on('click', 'a.guest-support-mass-delete', function(event) {
		let selectedValues = [];
		$('input#guest_support_tickets_select:checked').each(function(){
			selectedValues.push($(this).val());
		});

		if ( confirm("Are you sure? You can't undo this action.") ) {
			var post_vars = {
				'guest_support_handler': 'ajax',
				'request': 'delete_tickets',
				'ids': selectedValues
			};

			var data = $.post('', post_vars);
			data.done(function(reply_data) {
				location.reload();
			});
		}
	});

	/**
	 * Dropdown with multi select capability
	 */
	$( window ).on( 'click', function( event ) {
		if ( $( event.target ).closest( 'span.guest-support-multiselect-selected-item-delete' ).length ) {
			let thisselect = $( event.target ).closest( 'div.guest-support-multiselect' );
			let defaultPlaceholder = thisselect.find('div.guest-support-multiselect-placeholder');
			let thisitem = $( event.target ).closest( 'div.guest-support-multiselect-selected-item' );
			let thisvalue = thisitem.attr( 'data-value' );
			let matchingOption = thisselect.find( 'div.guest-support-multiselect-options-item[data-value="' + thisvalue + '"]' );
			let selectInput = thisselect.find( 'select.guest-support-multiselect-selectinput' );

			// Remove and add active class correctly
			if ( !thisselect.hasClass( 'active' ) ) {
				$( 'div.guest-support-multiselect' ).removeClass( 'active' );
				thisselect.addClass( 'active' );
			}

			// Show matching option and remove the selected item
			if ( matchingOption.length ) {
				thisitem.remove();
				matchingOption.removeClass('guest-support-multiselect-hide');

				// Deselect the option with value = thisvalue
				let optionToDeselect = selectInput.find( 'option[value="' + thisvalue + '"]' );

				// Remove the 'selected' property and attribute
				optionToDeselect.prop( 'selected', false ); // Update the property
				optionToDeselect.removeAttr( 'selected' );  // Remove the attribute from the HTML
				selectInput.trigger( 'change' );
			}

			// Show / hide placeholder
			let selectItems = thisselect.find( 'div.guest-support-multiselect-selected-item' );
			if ( selectItems.length ) {
				defaultPlaceholder.addClass('guest-support-multiselect-hide');
			} else {
				defaultPlaceholder.removeClass('guest-support-multiselect-hide');
			}
		} else if ( $( event.target ).closest( 'div.guest-support-multiselect-options-item' ).length ) {
			let thisselect = $( event.target ).closest( 'div.guest-support-multiselect' );
			let thisitem = $( event.target ).closest( 'div.guest-support-multiselect-options-item' );
			let defaultPlaceholder = thisselect.find('div.guest-support-multiselect-placeholder');
			let thisvalue = thisitem.attr( 'data-value' );
			let selectInput = thisselect.find( 'select.guest-support-multiselect-selectinput' );

			// Hide this item
			thisitem.addClass('guest-support-multiselect-hide');

			// Hide placeholder
			defaultPlaceholder.addClass('guest-support-multiselect-hide');

			// Add this item to selected item
			let selectedHtml = '<div class="guest-support-multiselect-selected-item" data-value="' + thisvalue + '"><span class="guest-support-multiselect-selected-item-text">' + thisitem.text() + '</span><span class="guest-support-multiselect-selected-item-delete"></span></div>';

			defaultPlaceholder.before(selectedHtml);

			// Select the selected option
			let optionToSelect = selectInput.find( 'option[value="' + thisvalue + '"]' );

			// Remove the 'selected' property and attribute
			optionToSelect.prop( 'selected', true ); // Update the property
			optionToSelect.attr( 'selected', 'selected' );  // Remove the attribute from the HTML
			selectInput.trigger( 'change' );
		} else if ( $( event.target ).closest( 'div.guest-support-multiselect-selected' ).length ) {
			let thisselect = $( event.target ).closest( 'div.guest-support-multiselect' );
			let hasVisibleItem = thisselect.find( 'div.guest-support-multiselect-options-item:visible' ).length > 0;
	
			// Toggle the active class based on the current state
			if ( thisselect.hasClass( 'active' ) ) {
				thisselect.removeClass( 'active' );
			} else if ( hasVisibleItem ) {
				$( 'div.guest-support-multiselect' ).removeClass( 'active' );
				thisselect.addClass( 'active' );
			} else {
				$( 'div.guest-support-multiselect' ).removeClass( 'active' );
			}
		} else {
			// If clicked outside, close all active multiselect options
			$( 'div.guest-support-multiselect' ).removeClass( 'active' );
		}
	});
});
