<?php
/**
 * @package     Guest Support
 * @author      RcaTheme.com <support@rcatheme.com>
 * @license     https://www.gnu.org/licenses/gpl-3.0.html GPLv3
 * @link        https://www.rcatheme.com
 * @copyright   2024 RcaTheme.com, All rights resered.
 */
defined('ABSPATH') or die;
// Check if user is in Admin area and can administrator
GuestSupportApp::verifyAdmin();

$handler = 'add_department';
$title = 'Add New Department';
$submit_button = esc_html__('Add New Department', 'guest-support');
$cancel_button = esc_html__('Go back', 'guest-support');

if ( $type == 'edit' && $dept_id )
{
    $handler = 'edit_department';
    $title = 'Edit Department: ' . $values['dept_name'];
    $submit_button = esc_html__('Edit Department', 'guest-support');
}

$forms = GuestSupportApp::getForms();

?>
<div class="wrap">
    <h1 class="wp-heading-inline"><?php esc_html_e( 'Support Departments', 'guest-support' ); ?></h1>

    <hr class="wp-header-end">
    <?php echo wp_kses_post( GuestSupportApp::getNotice() ); ?>

    <div class="guest-support-wp-heading-spacer">&nbsp;</div>

    <div class="form-wrap guest-support-departments-form">
        <h2><?php echo esc_html( $title ); ?></h2>
        <form id="guest_support_departments_form" method="post" action="" class="validate">
            <?php wp_nonce_field( '_wpnonce_department_form_action', '_wpnonce_department_form' ); ?>

            <div class="form-field form-required dept-name-wrap">
                <label for="dept-name"><?php esc_html_e( 'Department Name*', 'guest-support' ); ?></label>
                <input name="dept_name" id="dept-name" type="text" value="<?php echo esc_attr( $values['dept_name'] ); ?>" size="40" placeholder="Sales" aria-required="true" required>
            </div>

			<div class="form-field form-required dept-applicable-forms-wrap">
				<label for="guest_support_applicable_forms"><?php esc_html_e( 'Select Applicable Forms*', 'guest-support' ); ?></label>
				<?php
					$select_options = [];
					if ( !empty( $forms ) )
					{
						foreach ( $forms as $form ) {
							$select_options[] = [
								'value' => $form->id,
								'label' => $form->form_name,
							];
						}

						if ( empty( $selected_forms ) )
						{
							$selected_forms = [];
						}

						echo GuestSupportApp::wp_kses_extended_for_inputs( GuestSupportApp::multiselectHtml( $select_options, $selected_forms, 'applicable_forms', 'guest_support_applicable_forms', 'guest-support-applicable-forms' ) );
					}
				?>
			</div>

            <div class="form-field form-required dept-agent-wrap">
                <label for="dept-agent"><?php esc_html_e( 'Support Agent (for this Department)*', 'guest-support' ); ?></label>
                <input type="hidden" name="dept_agent" id="guest_support_dropdown_search_main" value="<?php echo esc_attr( $values['dept_agent'] ); ?>">
                <div class="guest-support-dropdown-search">
                    <?php
						$agentinfo = '';
                        if ( $values['dept_agent'] )
                        {
                            $user = get_userdata( $values['dept_agent'] );
							if ( $user !== false )
							{
								$agentinfo = $user->display_name . ' (' . $user->user_email . ')';
							}
                        }
                    ?>
                    <input type="text" id="guest_support_dropdown_search_box" class="guest-support-dropdown-search-box" size="40" placeholder="<?php esc_html_e( 'Type user email...', 'guest-support' ); ?>" value="<?php echo esc_attr( $agentinfo ); ?>" autocomplete="off">
                    <div class="guest-support-dropdown-search-text"><?php echo $agentinfo ? esc_html( $agentinfo ) : ''; ?></div>
                    <div id="guest_support_dropdown_search_menu" class="guest-support-dropdown-search-menu"></div>
                </div>
                <p><?php esc_html_e( "All new Tickets created for this Department will be assigned to this selected user. All new Tickets and Replies email notifications will send to this user's email address and as well as additional emails below.", "guest-support" ); ?></p>
            </div>

            <div class="form-field dept-name-wrap">
                <label for="dept-additional-emails"><?php esc_html_e( 'Additional Emails Notifications (each email in new line) - (keep empty to disable)', 'guest-support' ); ?></label>
                <textarea name="dept_additional_emails" id="dept-additional-emails" placeholder="user1@example.com&#10;user2@example.com&#10;user3@example.com" rows="5" cols="40"><?php echo esc_textarea( $values['dept_additional_emails'] ); ?></textarea>
                <p><?php esc_html_e( "Add additional email addresses if you want to receive email notifications for new Tickets and Replies submited to this Department.", "guest-support" ); ?></p>
            </div>

            <div class="form-field form-required dept-name-wrap">
                <label for="dept-additional-emails-type"><?php esc_html_e( 'Additional Emails Notifications Type', 'guest-support' ); ?></label>
                <select name="dept_additional_emails_type" id="dept-additional-emails-type">
                    <option value="both"<?php echo $values['dept_additional_emails_type'] == 'both' ? ' selected' : '';?>><?php esc_html_e( 'Both new Tickets and Replies', 'guest-support' ); ?></option>
                    <option value="tickets"<?php echo $values['dept_additional_emails_type'] == 'tickets' ? ' selected' : '';?>><?php esc_html_e( 'New Tickets only', 'guest-support' ); ?></option>
                    <option value="replies"<?php echo $values['dept_additional_emails_type'] == 'replies' ? ' selected' : '';?>><?php esc_html_e( 'Replies only', 'guest-support' ); ?></option>
                </select>
                <p><?php esc_html_e( "Choose how you want to receive email notifications to above Additional Email addresses.", "guest-support" ); ?></p>
            </div>

            <p class="submit">
                <input type="hidden" name="guest_support_handler" value="<?php echo esc_attr( $handler ); ?>">
                <input type="submit" id="submit" class="button button-primary" value="<?php echo esc_attr( $submit_button ); ?>">
                <a href="<?php echo esc_url( admin_url( 'admin.php?page=guest-support-departments' ) ); ?>" class="button button-cancel"><?php echo esc_attr( $cancel_button ); ?></a>
            </p>
        </form>
    </div>
</div>